;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "websearch" "20251026.2108"
  "Query search engines."
  '((emacs "24.4"))
  :url "https://gitlab.com/xgqt/emacs-websearch/"
  :commit "7d5700b1f0b9e276ab423e06f3f98d661c67b022"
  :revdesc "7d5700b1f0b9"
  :keywords '("convenience" "hypermedia")
  :authors '(("Maciej Barć" . "xgqt@xgqt.org"))
  :maintainers '(("Maciej Barć" . "xgqt@xgqt.org")))
